.. tensorboardX documentation master file, created by
   sphinx-quickstart on Wed Aug  9 01:38:01 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tensorboardX's documentation!
===============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tensorboard
   utils
   tutorial
   tutorial_zh

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
